# 1 "xml_lexer.mll"
 (*
 * Xml Light, an small Xml parser/printer with DTD support.
 * Copyright (C) 2003 Nicolas Cannasse (ncannasse@motion-twin.com)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library has the special exception on linking described in file
 * README.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301 USA
 *)

open Lexing
open Xml_parser
open Dtd

type error =
	| EUnterminatedComment
	| EUnterminatedString
	| EIdentExpected
	| ECloseExpected
	| ENodeExpected
	| EAttributeNameExpected
	| EAttributeValueExpected
	| EUnterminatedEntity

type dtd_error =
	| EInvalidDTDDecl
	| EInvalidDTDTag
	| EDTDItemExpected
	| EInvalidDTDElement
	| EInvalidDTDAttribute

exception Error of error
exception DTDError of dtd_error

type pos = int * int * int * int

type dtd_decl =
	| DTDFile of string
	| DTDData of dtd

type dtd_item_type =
	| TElement
	| TAttribute

type token =
	| Tag of string * (string * string) list * bool
	| PCData of string
	| Endtag of string
	| DocType of (string * dtd_decl)
	| Eof

let last_pos = ref 0
and current_line = ref 0
and current_line_start = ref 0

let tmp = Buffer.create 200


let entities = [
  "gt"  ,62, ">";
  "lt"  ,60, "<";
  "amp" ,38, "&";
  "apos",39, "'";
  "quot",34, "\"";
]

let idents = Hashtbl.create 0
let _ = begin
  List.iter (fun (str,code,res) ->
      Hashtbl.add idents (str^";") res;
      if code > 0
      then Hashtbl.add idents ("#" ^ string_of_int code ^ ";") res
    ) entities
end

let init lexbuf =
	current_line := 1;
	current_line_start := lexeme_start lexbuf;
	last_pos := !current_line_start

let close lexbuf =
	Buffer.reset tmp

let pos lexbuf =
	!current_line ,	!current_line_start ,
	!last_pos ,
	lexeme_start lexbuf

let restore (cl,cls,lp,_) =
	current_line := cl;
	current_line_start := cls;
	last_pos := lp

let newline lexbuf =
	incr current_line;
	last_pos := lexeme_end lexbuf;
	current_line_start := !last_pos

let error lexbuf e =
	last_pos := lexeme_start lexbuf;
	raise (Error e)

let dtd_error lexbuf e =
	last_pos := lexeme_start lexbuf;
	raise (DTDError e)

# 122 "xml_lexer.ml"
let __ocaml_lex_tables = {
  Lexing.lex_base =
   "\000\000\244\255\245\255\001\000\247\255\003\000\008\000\009\000\
    \255\255\011\000\017\000\250\255\000\000\001\000\000\000\000\000\
    \003\000\000\000\000\000\000\000\003\000\253\255\005\000\000\000\
    \001\000\009\000\001\000\252\255\251\255\020\000\044\000\255\255\
    \006\000\252\255\253\255\003\000\255\255\013\000\254\255\014\000\
    \252\255\253\255\016\000\255\255\254\255\005\000\251\255\000\000\
    \254\255\015\000\019\000\253\255\073\000\254\255\077\000\075\000\
    \253\255\150\000\237\000\255\255\056\001\160\000\254\255\134\001\
    \254\255\212\001\020\000\254\255\255\255\041\000\032\000\255\255\
    \254\255\034\002\254\255\112\002\211\000\253\255\212\000\213\000\
    \215\000\216\000\254\255\255\255\003\000\252\255\253\255\008\000\
    \255\255\254\255\017\000\252\255\253\255\015\000\255\255\254\255\
    \021\000\252\255\253\255\007\000\017\000\047\000\038\000\043\000\
    \051\000\255\255\036\000\036\000\052\000\045\000\254\255\132\000\
    \253\255\254\255\255\255\041\000\255\255\226\000\218\000\254\255\
    \255\255\074\000\254\255\255\255\078\000\253\255\001\000\010\000\
    \013\000\255\255\105\000\255\255\161\000\253\255\084\000\093\000\
    \101\000\141\000\154\000\150\000\145\000\255\255\148\000\157\000\
    \161\000\154\000\154\000\254\255\213\000\252\255\253\255\163\000\
    \163\000\153\000\255\255\172\000\171\000\171\000\254\255\201\000\
    \254\255\255\255\202\000\254\255\255\255\226\002\243\255\048\003\
    \245\255\246\255\247\255\186\000\249\255\250\255\251\255\252\255\
    \253\255\010\001\255\255\200\000\200\000\204\000\192\000\215\000\
    \248\255\104\003\250\255\251\255\213\000\206\000\216\000\230\000\
    \213\000\234\000\255\255\216\000\222\000\253\000\005\001\253\000\
    \254\255\250\000\045\001\046\001\252\255\135\003\254\255\213\003\
    \106\001\253\255\254\255\255\255\159\001\249\255\170\002\254\255\
    \255\255\048\001\045\001\042\001\051\001\067\001\064\001\077\001\
    \069\001\083\001\112\001\253\255\101\001\119\001\123\001\128\001\
    \157\001\252\255\139\001\159\001\190\001\251\255\189\001\206\001\
    \187\001\197\001\190\001\250\255\013\002\253\255\254\255\255\255\
    ";
  Lexing.lex_backtrk =
   "\255\255\255\255\255\255\009\000\255\255\007\000\001\000\001\000\
    \255\255\006\000\007\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\002\000\001\000\255\255\
    \255\255\255\255\255\255\003\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\003\000\255\255\255\255\255\255\255\255\003\000\
    \255\255\000\000\255\255\255\255\002\000\255\255\000\000\255\255\
    \255\255\002\000\002\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\255\255\255\255\255\255\002\000\255\255\255\255\
    \255\255\255\255\255\255\000\000\255\255\255\255\002\000\002\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\003\000\
    \255\255\255\255\255\255\255\255\255\255\003\000\255\255\255\255\
    \255\255\255\255\255\255\003\000\003\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\001\000\255\255\003\000\002\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\002\000\001\000\
    \255\255\255\255\001\000\255\255\255\255\255\255\002\000\002\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\003\000\
    \003\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\011\000\
    \255\255\255\255\255\255\012\000\255\255\255\255\255\255\255\255\
    \255\255\001\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\005\000\005\000\005\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\002\000\255\255\255\255\255\255\255\255\255\255\000\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\006\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    ";
  Lexing.lex_default =
   "\003\000\000\000\000\000\003\000\000\000\255\255\255\255\003\000\
    \000\000\255\255\255\255\000\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\000\000\255\255\255\255\
    \255\255\255\255\255\255\000\000\000\000\255\255\255\255\000\000\
    \033\000\000\000\000\000\255\255\000\000\255\255\000\000\040\000\
    \000\000\000\000\255\255\000\000\000\000\049\000\000\000\255\255\
    \000\000\049\000\255\255\000\000\054\000\000\000\054\000\056\000\
    \000\000\255\255\255\255\000\000\255\255\255\255\000\000\064\000\
    \000\000\255\255\067\000\000\000\000\000\255\255\255\255\000\000\
    \000\000\074\000\000\000\255\255\077\000\000\000\255\255\255\255\
    \255\255\255\255\000\000\000\000\085\000\000\000\000\000\255\255\
    \000\000\000\000\091\000\000\000\000\000\255\255\000\000\000\000\
    \097\000\000\000\000\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\255\255\255\255\255\255\255\255\000\000\112\000\
    \000\000\000\000\000\000\255\255\000\000\255\255\255\255\000\000\
    \000\000\122\000\000\000\000\000\125\000\000\000\255\255\255\255\
    \255\255\000\000\255\255\000\000\133\000\000\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\000\000\255\255\255\255\
    \255\255\255\255\255\255\000\000\149\000\000\000\000\000\255\255\
    \255\255\255\255\000\000\255\255\255\255\255\255\000\000\160\000\
    \000\000\000\000\163\000\000\000\000\000\166\000\000\000\255\255\
    \000\000\000\000\000\000\255\255\000\000\000\000\000\000\000\000\
    \000\000\255\255\000\000\255\255\255\255\255\255\255\255\255\255\
    \000\000\186\000\000\000\000\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\000\000\255\255\255\255\255\255\255\255\255\255\
    \000\000\255\255\255\255\255\255\000\000\206\000\000\000\255\255\
    \209\000\000\000\000\000\000\000\213\000\000\000\255\255\000\000\
    \000\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\000\000\255\255\255\255\255\255\255\255\
    \255\255\000\000\255\255\255\255\255\255\000\000\255\255\255\255\
    \255\255\255\255\255\255\000\000\245\000\000\000\000\000\000\000\
    ";
  Lexing.lex_trans =
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\007\000\008\000\255\255\010\000\006\000\255\255\048\000\
    \036\000\006\000\007\000\255\255\009\000\006\000\006\000\000\000\
    \043\000\255\255\010\000\000\000\000\000\030\000\031\000\000\000\
    \007\000\030\000\127\000\010\000\012\000\088\000\004\000\255\255\
    \006\000\007\000\089\000\009\000\000\000\013\000\028\000\255\255\
    \037\000\010\000\009\000\035\000\030\000\030\000\095\000\128\000\
    \094\000\030\000\129\000\000\000\005\000\255\255\001\000\255\255\
    \009\000\024\000\011\000\022\000\015\000\255\255\017\000\255\255\
    \021\000\023\000\026\000\038\000\030\000\042\000\044\000\016\000\
    \020\000\051\000\068\000\255\255\018\000\025\000\255\255\255\255\
    \070\000\019\000\255\255\014\000\027\000\050\000\072\000\087\000\
    \106\000\024\000\047\000\022\000\089\000\100\000\101\000\071\000\
    \099\000\023\000\026\000\095\000\255\255\093\000\057\000\053\000\
    \098\000\102\000\103\000\255\255\104\000\025\000\105\000\107\000\
    \108\000\109\000\110\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\255\255\116\000\255\255\
    \123\000\255\255\126\000\255\255\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\114\000\131\000\
    \142\000\136\000\137\000\113\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\061\000\061\000\
    \061\000\061\000\061\000\061\000\061\000\061\000\061\000\061\000\
    \061\000\061\000\061\000\061\000\061\000\061\000\061\000\061\000\
    \061\000\061\000\138\000\062\000\079\000\080\000\081\000\139\000\
    \080\000\081\000\134\000\118\000\140\000\141\000\135\000\118\000\
    \143\000\144\000\145\000\118\000\119\000\146\000\147\000\118\000\
    \155\000\153\000\154\000\079\000\080\000\081\000\083\000\080\000\
    \081\000\083\000\118\000\082\000\156\000\150\000\082\000\157\000\
    \002\000\255\255\118\000\086\000\158\000\046\000\034\000\161\000\
    \164\000\255\255\179\000\180\000\181\000\182\000\041\000\255\255\
    \078\000\092\000\080\000\177\000\183\000\080\000\152\000\177\000\
    \184\000\201\000\151\000\195\000\191\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\192\000\
    \059\000\193\000\177\000\194\000\196\000\197\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \198\000\255\255\199\000\200\000\202\000\255\255\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\203\000\059\000\204\000\238\000\234\000\228\000\
    \221\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\211\000\222\000\223\000\224\000\225\000\
    \226\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\065\000\227\000\229\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\216\000\214\000\230\000\231\000\232\000\215\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\233\000\120\000\235\000\236\000\065\000\210\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\237\000\239\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\240\000\
    \241\000\242\000\243\000\000\000\000\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\247\000\
    \000\000\000\000\000\000\065\000\246\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\075\000\
    \000\000\000\000\075\000\075\000\075\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\075\000\075\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\000\000\000\000\000\000\
    \000\000\075\000\000\000\075\000\075\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\075\000\000\000\000\000\
    \075\000\075\000\075\000\075\000\075\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\075\000\075\000\075\000\075\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\000\000\000\000\000\000\000\000\075\000\
    \000\000\075\000\075\000\075\000\075\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\177\000\178\000\000\000\217\000\177\000\
    \218\000\000\000\000\000\219\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\220\000\000\000\000\000\000\000\
    \000\000\000\000\177\000\000\000\000\000\171\000\000\000\000\000\
    \000\000\000\000\176\000\175\000\170\000\169\000\174\000\167\000\
    \000\000\000\000\167\000\167\000\167\000\167\000\167\000\167\000\
    \167\000\167\000\167\000\167\000\167\000\000\000\000\000\000\000\
    \173\000\168\000\000\000\167\000\167\000\167\000\167\000\167\000\
    \167\000\167\000\167\000\167\000\167\000\167\000\167\000\167\000\
    \167\000\167\000\167\000\167\000\167\000\167\000\167\000\167\000\
    \167\000\167\000\167\000\167\000\167\000\000\000\000\000\000\000\
    \000\000\167\000\000\000\167\000\167\000\167\000\167\000\167\000\
    \167\000\167\000\167\000\167\000\167\000\167\000\167\000\167\000\
    \167\000\167\000\167\000\167\000\167\000\167\000\167\000\167\000\
    \167\000\167\000\167\000\167\000\167\000\167\000\172\000\000\000\
    \167\000\167\000\167\000\167\000\167\000\167\000\167\000\167\000\
    \167\000\167\000\167\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\167\000\167\000\167\000\167\000\167\000\167\000\167\000\
    \167\000\167\000\167\000\167\000\167\000\167\000\167\000\167\000\
    \167\000\167\000\167\000\167\000\167\000\167\000\167\000\167\000\
    \167\000\167\000\167\000\000\000\000\000\000\000\000\000\167\000\
    \187\000\167\000\167\000\167\000\167\000\167\000\167\000\167\000\
    \167\000\167\000\167\000\167\000\167\000\167\000\167\000\167\000\
    \167\000\167\000\167\000\167\000\167\000\167\000\167\000\167\000\
    \167\000\167\000\167\000\190\000\000\000\000\000\000\000\000\000\
    \000\000\188\000\000\000\000\000\207\000\000\000\189\000\207\000\
    \207\000\207\000\207\000\207\000\207\000\207\000\207\000\207\000\
    \207\000\207\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \207\000\207\000\207\000\207\000\207\000\207\000\207\000\207\000\
    \207\000\207\000\207\000\207\000\207\000\207\000\207\000\207\000\
    \207\000\207\000\207\000\207\000\207\000\207\000\207\000\207\000\
    \207\000\207\000\000\000\000\000\000\000\000\000\207\000\000\000\
    \207\000\207\000\207\000\207\000\207\000\207\000\207\000\207\000\
    \207\000\207\000\207\000\207\000\207\000\207\000\207\000\207\000\
    \207\000\207\000\207\000\207\000\207\000\207\000\207\000\207\000\
    \207\000\207\000\207\000\000\000\000\000\207\000\207\000\207\000\
    \207\000\207\000\207\000\207\000\207\000\207\000\207\000\207\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\207\000\207\000\
    \207\000\207\000\207\000\207\000\207\000\207\000\207\000\207\000\
    \207\000\207\000\207\000\207\000\207\000\207\000\207\000\207\000\
    \207\000\207\000\207\000\207\000\207\000\207\000\207\000\207\000\
    \000\000\000\000\000\000\000\000\207\000\000\000\207\000\207\000\
    \207\000\207\000\207\000\207\000\207\000\207\000\207\000\207\000\
    \207\000\207\000\207\000\207\000\207\000\207\000\207\000\207\000\
    \207\000\207\000\207\000\207\000\207\000\207\000\207\000\207\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000";
  Lexing.lex_check =
   "\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\000\000\003\000\005\000\000\000\003\000\045\000\
    \032\000\006\000\007\000\007\000\009\000\006\000\007\000\255\255\
    \039\000\049\000\010\000\255\255\255\255\029\000\029\000\255\255\
    \000\000\029\000\126\000\005\000\005\000\084\000\000\000\003\000\
    \006\000\007\000\087\000\009\000\255\255\012\000\013\000\007\000\
    \035\000\010\000\005\000\032\000\029\000\030\000\093\000\127\000\
    \090\000\030\000\128\000\255\255\000\000\003\000\000\000\003\000\
    \010\000\023\000\005\000\014\000\012\000\007\000\016\000\007\000\
    \020\000\022\000\025\000\037\000\030\000\039\000\042\000\015\000\
    \019\000\050\000\066\000\052\000\017\000\024\000\052\000\054\000\
    \069\000\018\000\054\000\012\000\026\000\047\000\070\000\084\000\
    \099\000\023\000\045\000\014\000\087\000\096\000\100\000\069\000\
    \096\000\022\000\025\000\093\000\049\000\090\000\055\000\052\000\
    \096\000\101\000\102\000\054\000\103\000\024\000\104\000\106\000\
    \107\000\108\000\109\000\055\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\052\000\115\000\052\000\
    \121\000\054\000\124\000\054\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\111\000\130\000\
    \134\000\135\000\136\000\111\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\057\000\057\000\
    \057\000\057\000\057\000\057\000\057\000\057\000\057\000\057\000\
    \061\000\061\000\061\000\061\000\061\000\061\000\061\000\061\000\
    \061\000\061\000\137\000\061\000\076\000\078\000\079\000\138\000\
    \080\000\081\000\132\000\118\000\139\000\140\000\132\000\118\000\
    \142\000\143\000\144\000\117\000\117\000\145\000\146\000\117\000\
    \151\000\152\000\153\000\076\000\078\000\079\000\078\000\080\000\
    \081\000\080\000\118\000\078\000\155\000\148\000\080\000\156\000\
    \000\000\003\000\117\000\084\000\157\000\045\000\032\000\159\000\
    \162\000\007\000\171\000\179\000\180\000\181\000\039\000\049\000\
    \076\000\090\000\079\000\177\000\182\000\081\000\148\000\177\000\
    \183\000\188\000\148\000\189\000\190\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\058\000\191\000\
    \058\000\192\000\177\000\193\000\195\000\196\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \197\000\052\000\198\000\199\000\201\000\054\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\202\000\060\000\203\000\217\000\218\000\219\000\
    \220\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\208\000\221\000\222\000\223\000\224\000\
    \225\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\063\000\226\000\228\000\063\000\063\000\
    \063\000\063\000\063\000\063\000\063\000\063\000\063\000\063\000\
    \063\000\212\000\212\000\229\000\230\000\231\000\212\000\063\000\
    \063\000\063\000\063\000\063\000\063\000\063\000\063\000\063\000\
    \063\000\063\000\063\000\063\000\063\000\063\000\063\000\063\000\
    \063\000\063\000\063\000\063\000\063\000\063\000\063\000\063\000\
    \063\000\232\000\117\000\234\000\235\000\063\000\208\000\063\000\
    \063\000\063\000\063\000\063\000\063\000\063\000\063\000\063\000\
    \063\000\063\000\063\000\063\000\063\000\063\000\063\000\063\000\
    \063\000\063\000\063\000\063\000\063\000\063\000\063\000\063\000\
    \063\000\065\000\236\000\238\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\239\000\
    \240\000\241\000\242\000\255\255\255\255\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\244\000\
    \255\255\255\255\255\255\065\000\244\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\073\000\
    \255\255\255\255\073\000\073\000\073\000\073\000\073\000\073\000\
    \073\000\073\000\073\000\073\000\073\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\073\000\073\000\073\000\073\000\073\000\
    \073\000\073\000\073\000\073\000\073\000\073\000\073\000\073\000\
    \073\000\073\000\073\000\073\000\073\000\073\000\073\000\073\000\
    \073\000\073\000\073\000\073\000\073\000\255\255\255\255\255\255\
    \255\255\073\000\255\255\073\000\073\000\073\000\073\000\073\000\
    \073\000\073\000\073\000\073\000\073\000\073\000\073\000\073\000\
    \073\000\073\000\073\000\073\000\073\000\073\000\073\000\073\000\
    \073\000\073\000\073\000\073\000\073\000\075\000\255\255\255\255\
    \075\000\075\000\075\000\075\000\075\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\075\000\075\000\075\000\075\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\255\255\255\255\255\255\255\255\075\000\
    \255\255\075\000\075\000\075\000\075\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\165\000\165\000\255\255\214\000\165\000\
    \214\000\255\255\255\255\214\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\214\000\255\255\255\255\255\255\
    \255\255\255\255\165\000\255\255\255\255\165\000\255\255\255\255\
    \255\255\255\255\165\000\165\000\165\000\165\000\165\000\165\000\
    \255\255\255\255\165\000\165\000\165\000\165\000\165\000\165\000\
    \165\000\165\000\165\000\165\000\165\000\255\255\255\255\255\255\
    \165\000\165\000\255\255\165\000\165\000\165\000\165\000\165\000\
    \165\000\165\000\165\000\165\000\165\000\165\000\165\000\165\000\
    \165\000\165\000\165\000\165\000\165\000\165\000\165\000\165\000\
    \165\000\165\000\165\000\165\000\165\000\255\255\255\255\255\255\
    \255\255\165\000\255\255\165\000\165\000\165\000\165\000\165\000\
    \165\000\165\000\165\000\165\000\165\000\165\000\165\000\165\000\
    \165\000\165\000\165\000\165\000\165\000\165\000\165\000\165\000\
    \165\000\165\000\165\000\165\000\165\000\167\000\165\000\255\255\
    \167\000\167\000\167\000\167\000\167\000\167\000\167\000\167\000\
    \167\000\167\000\167\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\167\000\167\000\167\000\167\000\167\000\167\000\167\000\
    \167\000\167\000\167\000\167\000\167\000\167\000\167\000\167\000\
    \167\000\167\000\167\000\167\000\167\000\167\000\167\000\167\000\
    \167\000\167\000\167\000\255\255\255\255\255\255\255\255\167\000\
    \185\000\167\000\167\000\167\000\167\000\167\000\167\000\167\000\
    \167\000\167\000\167\000\167\000\167\000\167\000\167\000\167\000\
    \167\000\167\000\167\000\167\000\167\000\167\000\167\000\167\000\
    \167\000\167\000\167\000\185\000\255\255\255\255\255\255\255\255\
    \255\255\185\000\255\255\255\255\205\000\255\255\185\000\205\000\
    \205\000\205\000\205\000\205\000\205\000\205\000\205\000\205\000\
    \205\000\205\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \205\000\205\000\205\000\205\000\205\000\205\000\205\000\205\000\
    \205\000\205\000\205\000\205\000\205\000\205\000\205\000\205\000\
    \205\000\205\000\205\000\205\000\205\000\205\000\205\000\205\000\
    \205\000\205\000\255\255\255\255\255\255\255\255\205\000\255\255\
    \205\000\205\000\205\000\205\000\205\000\205\000\205\000\205\000\
    \205\000\205\000\205\000\205\000\205\000\205\000\205\000\205\000\
    \205\000\205\000\205\000\205\000\205\000\205\000\205\000\205\000\
    \205\000\205\000\207\000\255\255\255\255\207\000\207\000\207\000\
    \207\000\207\000\207\000\207\000\207\000\207\000\207\000\207\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\207\000\207\000\
    \207\000\207\000\207\000\207\000\207\000\207\000\207\000\207\000\
    \207\000\207\000\207\000\207\000\207\000\207\000\207\000\207\000\
    \207\000\207\000\207\000\207\000\207\000\207\000\207\000\207\000\
    \255\255\255\255\255\255\255\255\207\000\255\255\207\000\207\000\
    \207\000\207\000\207\000\207\000\207\000\207\000\207\000\207\000\
    \207\000\207\000\207\000\207\000\207\000\207\000\207\000\207\000\
    \207\000\207\000\207\000\207\000\207\000\207\000\207\000\207\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255";
  Lexing.lex_base_code =
   "";
  Lexing.lex_backtrk_code =
   "";
  Lexing.lex_default_code =
   "";
  Lexing.lex_trans_code =
   "";
  Lexing.lex_check_code =
   "";
  Lexing.lex_code =
   "";
}

let rec token lexbuf =
   __ocaml_lex_token_rec lexbuf 0
and __ocaml_lex_token_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 131 "xml_lexer.mll"
  (
			newline lexbuf;
			token lexbuf
		)
# 559 "xml_lexer.ml"

  | 1 ->
# 136 "xml_lexer.mll"
  (
			last_pos := lexeme_end lexbuf;
			token lexbuf
		)
# 567 "xml_lexer.ml"

  | 2 ->
# 141 "xml_lexer.mll"
  (
			last_pos := lexeme_start lexbuf;
			ignore_spaces lexbuf;
			let root = ident_name lexbuf in
			ignore_spaces lexbuf;
			let data = dtd_data lexbuf in
			DocType (root, data)
		)
# 579 "xml_lexer.ml"

  | 3 ->
# 150 "xml_lexer.mll"
  (
			last_pos := lexeme_start lexbuf;
			Buffer.reset tmp;
			PCData (cdata lexbuf)
		)
# 588 "xml_lexer.ml"

  | 4 ->
# 156 "xml_lexer.mll"
  (
			last_pos := lexeme_start lexbuf;
			comment lexbuf;
			token lexbuf
		)
# 597 "xml_lexer.ml"

  | 5 ->
# 162 "xml_lexer.mll"
  (
			last_pos := lexeme_start lexbuf;
			header lexbuf;
			token lexbuf;
		)
# 606 "xml_lexer.ml"

  | 6 ->
# 168 "xml_lexer.mll"
  (
			last_pos := lexeme_start lexbuf;
			let tag = ident_name lexbuf in
			ignore_spaces lexbuf;
			close_tag lexbuf;
			Endtag tag
		)
# 617 "xml_lexer.ml"

  | 7 ->
# 176 "xml_lexer.mll"
  (
			last_pos := lexeme_start lexbuf;
			let tag = ident_name lexbuf in
			ignore_spaces lexbuf;
			let attribs, closed = attributes lexbuf in
			Tag(tag, attribs, closed)
		)
# 628 "xml_lexer.ml"

  | 8 ->
# 184 "xml_lexer.mll"
  (
			last_pos := lexeme_start lexbuf;
			Buffer.reset tmp;
			Buffer.add_string tmp (entity lexbuf);
			PCData (pcdata lexbuf)
		)
# 638 "xml_lexer.ml"

  | 9 ->
# 191 "xml_lexer.mll"
  (
			last_pos := lexeme_start lexbuf;
			Buffer.reset tmp;
			Buffer.add_string tmp (lexeme lexbuf);
			PCData (pcdata lexbuf)
		)
# 648 "xml_lexer.ml"

  | 10 ->
# 197 "xml_lexer.mll"
       ( Eof )
# 653 "xml_lexer.ml"

  | 11 ->
# 199 "xml_lexer.mll"
  ( error lexbuf ENodeExpected )
# 658 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_token_rec lexbuf __ocaml_lex_state

and ignore_spaces lexbuf =
   __ocaml_lex_ignore_spaces_rec lexbuf 29
and __ocaml_lex_ignore_spaces_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 203 "xml_lexer.mll"
  (
			newline lexbuf;
			ignore_spaces lexbuf
		)
# 673 "xml_lexer.ml"

  | 1 ->
# 208 "xml_lexer.mll"
  ( ignore_spaces lexbuf )
# 678 "xml_lexer.ml"

  | 2 ->
# 210 "xml_lexer.mll"
  ( () )
# 683 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_ignore_spaces_rec lexbuf __ocaml_lex_state

and comment lexbuf =
   __ocaml_lex_comment_rec lexbuf 32
and __ocaml_lex_comment_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 214 "xml_lexer.mll"
  (
			newline lexbuf;
			comment lexbuf
		)
# 698 "xml_lexer.ml"

  | 1 ->
# 219 "xml_lexer.mll"
  ( () )
# 703 "xml_lexer.ml"

  | 2 ->
# 221 "xml_lexer.mll"
  ( raise (Error EUnterminatedComment) )
# 708 "xml_lexer.ml"

  | 3 ->
# 223 "xml_lexer.mll"
  ( comment lexbuf )
# 713 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_comment_rec lexbuf __ocaml_lex_state

and header lexbuf =
   __ocaml_lex_header_rec lexbuf 39
and __ocaml_lex_header_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 227 "xml_lexer.mll"
  (
			newline lexbuf;
			header lexbuf
		)
# 728 "xml_lexer.ml"

  | 1 ->
# 232 "xml_lexer.mll"
  ( () )
# 733 "xml_lexer.ml"

  | 2 ->
# 234 "xml_lexer.mll"
  ( error lexbuf ECloseExpected )
# 738 "xml_lexer.ml"

  | 3 ->
# 236 "xml_lexer.mll"
  ( header lexbuf )
# 743 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_header_rec lexbuf __ocaml_lex_state

and cdata lexbuf =
   __ocaml_lex_cdata_rec lexbuf 45
and __ocaml_lex_cdata_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 240 "xml_lexer.mll"
  (
			Buffer.add_string tmp (lexeme lexbuf);
			cdata lexbuf
		)
# 758 "xml_lexer.ml"

  | 1 ->
# 245 "xml_lexer.mll"
  (
			newline lexbuf;
			Buffer.add_string tmp (lexeme lexbuf);
			cdata lexbuf
		)
# 767 "xml_lexer.ml"

  | 2 ->
# 251 "xml_lexer.mll"
  ( Buffer.contents tmp )
# 772 "xml_lexer.ml"

  | 3 ->
# 253 "xml_lexer.mll"
  (
			Buffer.add_string tmp (lexeme lexbuf);
			cdata lexbuf
		)
# 780 "xml_lexer.ml"

  | 4 ->
# 258 "xml_lexer.mll"
  ( error lexbuf ECloseExpected )
# 785 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_cdata_rec lexbuf __ocaml_lex_state

and pcdata lexbuf =
   __ocaml_lex_pcdata_rec lexbuf 52
and __ocaml_lex_pcdata_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 262 "xml_lexer.mll"
  (
			Buffer.add_string tmp (lexeme lexbuf);
			pcdata lexbuf
		)
# 800 "xml_lexer.ml"

  | 1 ->
# 267 "xml_lexer.mll"
  (
			Buffer.add_string tmp (entity lexbuf);
			pcdata lexbuf
		)
# 808 "xml_lexer.ml"

  | 2 ->
# 272 "xml_lexer.mll"
  ( Buffer.contents tmp )
# 813 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_pcdata_rec lexbuf __ocaml_lex_state

and entity lexbuf =
   __ocaml_lex_entity_rec lexbuf 55
and __ocaml_lex_entity_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 276 "xml_lexer.mll"
  (
			let ident = lexeme lexbuf in
			try
				Hashtbl.find idents (String.lowercase ident)
			with
				Not_found -> "&" ^ ident
		)
# 831 "xml_lexer.ml"

  | 1 ->
# 284 "xml_lexer.mll"
    (
			let ident = lexeme lexbuf in
			try
				Hashtbl.find idents (String.lowercase ident)
			with
				Not_found -> "&" ^ ident
    )
# 842 "xml_lexer.ml"

  | 2 ->
# 292 "xml_lexer.mll"
  ( raise (Error EUnterminatedEntity) )
# 847 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_entity_rec lexbuf __ocaml_lex_state

and ident_name lexbuf =
   __ocaml_lex_ident_name_rec lexbuf 63
and __ocaml_lex_ident_name_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 296 "xml_lexer.mll"
  ( lexeme lexbuf )
# 859 "xml_lexer.ml"

  | 1 ->
# 298 "xml_lexer.mll"
  ( error lexbuf EIdentExpected )
# 864 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_ident_name_rec lexbuf __ocaml_lex_state

and close_tag lexbuf =
   __ocaml_lex_close_tag_rec lexbuf 66
and __ocaml_lex_close_tag_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 302 "xml_lexer.mll"
  ( () )
# 876 "xml_lexer.ml"

  | 1 ->
# 304 "xml_lexer.mll"
  ( error lexbuf ECloseExpected )
# 881 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_close_tag_rec lexbuf __ocaml_lex_state

and attributes lexbuf =
   __ocaml_lex_attributes_rec lexbuf 69
and __ocaml_lex_attributes_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 308 "xml_lexer.mll"
  ( [], false )
# 893 "xml_lexer.ml"

  | 1 ->
# 310 "xml_lexer.mll"
  ( [], true )
# 898 "xml_lexer.ml"

  | 2 ->
# 312 "xml_lexer.mll"
  (
			let key = attribute lexbuf in
			let data = attribute_data lexbuf in
			ignore_spaces lexbuf;
			let others, closed = attributes lexbuf in
			(key, data) :: others, closed
		)
# 909 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_attributes_rec lexbuf __ocaml_lex_state

and attribute lexbuf =
   __ocaml_lex_attribute_rec lexbuf 73
and __ocaml_lex_attribute_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 322 "xml_lexer.mll"
  ( lexeme lexbuf )
# 921 "xml_lexer.ml"

  | 1 ->
# 324 "xml_lexer.mll"
  ( error lexbuf EAttributeNameExpected )
# 926 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_attribute_rec lexbuf __ocaml_lex_state

and attribute_data lexbuf =
   __ocaml_lex_attribute_data_rec lexbuf 76
and __ocaml_lex_attribute_data_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 328 "xml_lexer.mll"
  (
			Buffer.reset tmp;
			last_pos := lexeme_end lexbuf;
			dq_string lexbuf
		)
# 942 "xml_lexer.ml"

  | 1 ->
# 334 "xml_lexer.mll"
  (
			Buffer.reset tmp;
			last_pos := lexeme_end lexbuf;
			q_string lexbuf
		)
# 951 "xml_lexer.ml"

  | 2 ->
# 340 "xml_lexer.mll"
  ( error lexbuf EAttributeValueExpected )
# 956 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_attribute_data_rec lexbuf __ocaml_lex_state

and dq_string lexbuf =
   __ocaml_lex_dq_string_rec lexbuf 84
and __ocaml_lex_dq_string_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 344 "xml_lexer.mll"
  ( Buffer.contents tmp )
# 968 "xml_lexer.ml"

  | 1 ->
# 346 "xml_lexer.mll"
  (
			Buffer.add_char tmp (lexeme_char lexbuf 1);
			dq_string lexbuf
		)
# 976 "xml_lexer.ml"

  | 2 ->
# 351 "xml_lexer.mll"
  ( raise (Error EUnterminatedString) )
# 981 "xml_lexer.ml"

  | 3 ->
# 353 "xml_lexer.mll"
  (
			Buffer.add_char tmp (lexeme_char lexbuf 0);
			dq_string lexbuf
		)
# 989 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dq_string_rec lexbuf __ocaml_lex_state

and q_string lexbuf =
   __ocaml_lex_q_string_rec lexbuf 90
and __ocaml_lex_q_string_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 360 "xml_lexer.mll"
  ( Buffer.contents tmp )
# 1001 "xml_lexer.ml"

  | 1 ->
# 362 "xml_lexer.mll"
  (
			Buffer.add_char tmp (lexeme_char lexbuf 1);
			q_string lexbuf
		)
# 1009 "xml_lexer.ml"

  | 2 ->
# 367 "xml_lexer.mll"
  ( raise (Error EUnterminatedString) )
# 1014 "xml_lexer.ml"

  | 3 ->
# 369 "xml_lexer.mll"
  (
			Buffer.add_char tmp (lexeme_char lexbuf 0);
			q_string lexbuf
		)
# 1022 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_q_string_rec lexbuf __ocaml_lex_state

and dtd_data lexbuf =
   __ocaml_lex_dtd_data_rec lexbuf 96
and __ocaml_lex_dtd_data_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 376 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			(* skipping Public ID *)
			let _ = dtd_file lexbuf in
			let file = dtd_file lexbuf in
			dtd_end_decl lexbuf;
			DTDFile file
		)
# 1041 "xml_lexer.ml"

  | 1 ->
# 385 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			let file = dtd_file lexbuf in
			dtd_end_decl lexbuf;
			DTDFile file
		)
# 1051 "xml_lexer.ml"

  | 2 ->
# 392 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			let data = dtd_intern lexbuf in
			dtd_end_decl lexbuf;
			DTDData data
		)
# 1061 "xml_lexer.ml"

  | 3 ->
# 399 "xml_lexer.mll"
  ( dtd_error lexbuf EInvalidDTDDecl )
# 1066 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dtd_data_rec lexbuf __ocaml_lex_state

and dtd_file lexbuf =
   __ocaml_lex_dtd_file_rec lexbuf 111
and __ocaml_lex_dtd_file_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 403 "xml_lexer.mll"
  (
			Buffer.reset tmp;
			let s = dq_string lexbuf in
			ignore_spaces lexbuf;
			s
		)
# 1083 "xml_lexer.ml"

  | 1 ->
# 410 "xml_lexer.mll"
  (
			Buffer.reset tmp;
			let s = q_string lexbuf in
			ignore_spaces lexbuf;
			s
		)
# 1093 "xml_lexer.ml"

  | 2 ->
# 417 "xml_lexer.mll"
  ( dtd_error lexbuf EInvalidDTDDecl )
# 1098 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dtd_file_rec lexbuf __ocaml_lex_state

and dtd_intern lexbuf =
   __ocaml_lex_dtd_intern_rec lexbuf 115
and __ocaml_lex_dtd_intern_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 421 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			[]
		)
# 1113 "xml_lexer.ml"

  | 1 ->
# 426 "xml_lexer.mll"
  (
			let l = dtd_item lexbuf in
			l @ (dtd_intern lexbuf)
		)
# 1121 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dtd_intern_rec lexbuf __ocaml_lex_state

and dtd lexbuf =
   __ocaml_lex_dtd_rec lexbuf 117
and __ocaml_lex_dtd_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 433 "xml_lexer.mll"
  ( [] )
# 1133 "xml_lexer.ml"

  | 1 ->
# 435 "xml_lexer.mll"
  (
			newline lexbuf;
			dtd lexbuf
		)
# 1141 "xml_lexer.ml"

  | 2 ->
# 440 "xml_lexer.mll"
  ( dtd lexbuf )
# 1146 "xml_lexer.ml"

  | 3 ->
# 442 "xml_lexer.mll"
  (
			let l = dtd_item lexbuf in
			l @ (dtd lexbuf)
		)
# 1154 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dtd_rec lexbuf __ocaml_lex_state

and dtd_end_decl lexbuf =
   __ocaml_lex_dtd_end_decl_rec lexbuf 121
and __ocaml_lex_dtd_end_decl_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 449 "xml_lexer.mll"
  ( ignore_spaces lexbuf )
# 1166 "xml_lexer.ml"

  | 1 ->
# 451 "xml_lexer.mll"
  ( dtd_error lexbuf EInvalidDTDDecl )
# 1171 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dtd_end_decl_rec lexbuf __ocaml_lex_state

and dtd_item lexbuf =
   __ocaml_lex_dtd_item_rec lexbuf 124
and __ocaml_lex_dtd_item_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 455 "xml_lexer.mll"
  (
			comment lexbuf;
			[];
		)
# 1186 "xml_lexer.ml"

  | 1 ->
# 460 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			let t = dtd_item_type lexbuf in
			let name = (try ident_name lexbuf with Error EIdentExpected -> raise (DTDError EInvalidDTDDecl)) in
			ignore_spaces lexbuf;
			match t with
			| TElement -> [ DTDElement (name , (dtd_element_type lexbuf)) ]
			| TAttribute -> List.map (fun (attrname,atype,adef) -> DTDAttribute (name, attrname, atype, adef)) (dtd_attributes lexbuf)
		)
# 1199 "xml_lexer.ml"

  | 2 ->
# 470 "xml_lexer.mll"
  (  dtd_error lexbuf EDTDItemExpected )
# 1204 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dtd_item_rec lexbuf __ocaml_lex_state

and dtd_attributes lexbuf =
   __ocaml_lex_dtd_attributes_rec lexbuf 130
and __ocaml_lex_dtd_attributes_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 474 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			[]
		)
# 1219 "xml_lexer.ml"

  | 1 ->
# 479 "xml_lexer.mll"
  (
			let attrname = (try ident_name lexbuf with Error EIdentExpected -> raise (DTDError EInvalidDTDAttribute)) in
			ignore_spaces lexbuf;
			let atype = dtd_attr_type lexbuf in
			let adef = dtd_attr_default lexbuf in
			let a = (attrname, atype, adef) in
			a :: (dtd_attributes lexbuf)
		)
# 1231 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dtd_attributes_rec lexbuf __ocaml_lex_state

and dtd_item_type lexbuf =
   __ocaml_lex_dtd_item_type_rec lexbuf 132
and __ocaml_lex_dtd_item_type_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 490 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			TElement
		)
# 1246 "xml_lexer.ml"

  | 1 ->
# 495 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			TAttribute
		)
# 1254 "xml_lexer.ml"

  | 2 ->
# 500 "xml_lexer.mll"
  ( dtd_error lexbuf EInvalidDTDTag )
# 1259 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dtd_item_type_rec lexbuf __ocaml_lex_state

and dtd_element_type lexbuf =
   __ocaml_lex_dtd_element_type_rec lexbuf 148
and __ocaml_lex_dtd_element_type_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 504 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			dtd_end_element lexbuf;
			DTDAny
		)
# 1275 "xml_lexer.ml"

  | 1 ->
# 510 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			dtd_end_element lexbuf;
			DTDEmpty
		)
# 1284 "xml_lexer.ml"

  | 2 ->
# 516 "xml_lexer.mll"
  (
			try
				let item = Xml_parser.dtd_element dtd_element_token lexbuf in
				ignore_spaces lexbuf;
				DTDChild item
			with
				Parsing.Parse_error -> dtd_error lexbuf EInvalidDTDElement
		)
# 1296 "xml_lexer.ml"

  | 3 ->
# 525 "xml_lexer.mll"
  ( dtd_error lexbuf EInvalidDTDElement )
# 1301 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dtd_element_type_rec lexbuf __ocaml_lex_state

and dtd_end_element lexbuf =
   __ocaml_lex_dtd_end_element_rec lexbuf 159
and __ocaml_lex_dtd_end_element_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 529 "xml_lexer.mll"
  ( ignore_spaces lexbuf )
# 1313 "xml_lexer.ml"

  | 1 ->
# 531 "xml_lexer.mll"
  ( dtd_error lexbuf EInvalidDTDElement )
# 1318 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dtd_end_element_rec lexbuf __ocaml_lex_state

and dtd_end_attribute lexbuf =
   __ocaml_lex_dtd_end_attribute_rec lexbuf 162
and __ocaml_lex_dtd_end_attribute_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 535 "xml_lexer.mll"
  ( ignore_spaces lexbuf )
# 1330 "xml_lexer.ml"

  | 1 ->
# 537 "xml_lexer.mll"
  ( dtd_error lexbuf EInvalidDTDAttribute )
# 1335 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dtd_end_attribute_rec lexbuf __ocaml_lex_state

and dtd_element_token lexbuf =
   __ocaml_lex_dtd_element_token_rec lexbuf 165
and __ocaml_lex_dtd_element_token_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 541 "xml_lexer.mll"
  (
			newline lexbuf;
			dtd_element_token lexbuf
		)
# 1350 "xml_lexer.ml"

  | 1 ->
# 546 "xml_lexer.mll"
  ( dtd_element_token lexbuf )
# 1355 "xml_lexer.ml"

  | 2 ->
# 548 "xml_lexer.mll"
  ( OPEN )
# 1360 "xml_lexer.ml"

  | 3 ->
# 550 "xml_lexer.mll"
  ( CLOSE )
# 1365 "xml_lexer.ml"

  | 4 ->
# 552 "xml_lexer.mll"
  ( NEXT )
# 1370 "xml_lexer.ml"

  | 5 ->
# 554 "xml_lexer.mll"
  ( END )
# 1375 "xml_lexer.ml"

  | 6 ->
# 556 "xml_lexer.mll"
  ( OR )
# 1380 "xml_lexer.ml"

  | 7 ->
# 558 "xml_lexer.mll"
  ( PCDATA )
# 1385 "xml_lexer.ml"

  | 8 ->
# 560 "xml_lexer.mll"
  ( STAR )
# 1390 "xml_lexer.ml"

  | 9 ->
# 562 "xml_lexer.mll"
  ( PLUS )
# 1395 "xml_lexer.ml"

  | 10 ->
# 564 "xml_lexer.mll"
  ( QUESTION )
# 1400 "xml_lexer.ml"

  | 11 ->
# 566 "xml_lexer.mll"
  ( IDENT (lexeme lexbuf) )
# 1405 "xml_lexer.ml"

  | 12 ->
# 568 "xml_lexer.mll"
  ( dtd_error lexbuf EInvalidDTDElement )
# 1410 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dtd_element_token_rec lexbuf __ocaml_lex_state

and dtd_attr_type lexbuf =
   __ocaml_lex_dtd_attr_type_rec lexbuf 185
and __ocaml_lex_dtd_attr_type_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 572 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			DTDCData
		)
# 1425 "xml_lexer.ml"

  | 1 ->
# 577 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			DTDNMToken
		)
# 1433 "xml_lexer.ml"

  | 2 ->
# 582 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
		 	DTDID
		)
# 1441 "xml_lexer.ml"

  | 3 ->
# 587 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			DTDIDRef
		)
# 1449 "xml_lexer.ml"

  | 4 ->
# 592 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			DTDEnum (dtd_attr_enum lexbuf)
		)
# 1457 "xml_lexer.ml"

  | 5 ->
# 597 "xml_lexer.mll"
  ( dtd_error lexbuf EInvalidDTDAttribute )
# 1462 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dtd_attr_type_rec lexbuf __ocaml_lex_state

and dtd_attr_enum lexbuf =
   __ocaml_lex_dtd_attr_enum_rec lexbuf 205
and __ocaml_lex_dtd_attr_enum_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 601 "xml_lexer.mll"
  (
			let v = lexeme lexbuf in
			ignore_spaces lexbuf;
			v :: (dtd_attr_enum_next lexbuf)
		)
# 1478 "xml_lexer.ml"

  | 1 ->
# 607 "xml_lexer.mll"
  ( dtd_error lexbuf EInvalidDTDAttribute )
# 1483 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dtd_attr_enum_rec lexbuf __ocaml_lex_state

and dtd_attr_enum_next lexbuf =
   __ocaml_lex_dtd_attr_enum_next_rec lexbuf 208
and __ocaml_lex_dtd_attr_enum_next_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 611 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			[]
		)
# 1498 "xml_lexer.ml"

  | 1 ->
# 616 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			dtd_attr_enum lexbuf
		)
# 1506 "xml_lexer.ml"

  | 2 ->
# 621 "xml_lexer.mll"
  ( dtd_error lexbuf EInvalidDTDAttribute )
# 1511 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dtd_attr_enum_next_rec lexbuf __ocaml_lex_state

and dtd_attr_default lexbuf =
   __ocaml_lex_dtd_attr_default_rec lexbuf 212
and __ocaml_lex_dtd_attr_default_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 625 "xml_lexer.mll"
  (
			Buffer.reset tmp;
			let v = (try dq_string lexbuf with Error EUnterminatedString -> raise (DTDError EInvalidDTDAttribute)) in
			ignore_spaces lexbuf;
			DTDDefault v
		)
# 1528 "xml_lexer.ml"

  | 1 ->
# 632 "xml_lexer.mll"
  (
			Buffer.reset tmp;
			let v = (try q_string lexbuf with Error EUnterminatedString -> raise (DTDError EInvalidDTDAttribute)) in
			ignore_spaces lexbuf;
			DTDDefault v
		)
# 1538 "xml_lexer.ml"

  | 2 ->
# 639 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			DTDRequired
		)
# 1546 "xml_lexer.ml"

  | 3 ->
# 644 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			DTDImplied
		)
# 1554 "xml_lexer.ml"

  | 4 ->
# 649 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			DTDFixed (dtd_attr_string lexbuf)
		)
# 1562 "xml_lexer.ml"

  | 5 ->
# 654 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			DTDDefault (dtd_attr_string lexbuf)
		)
# 1570 "xml_lexer.ml"

  | 6 ->
# 659 "xml_lexer.mll"
  ( dtd_error lexbuf EInvalidDTDAttribute )
# 1575 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dtd_attr_default_rec lexbuf __ocaml_lex_state

and dtd_attr_string lexbuf =
   __ocaml_lex_dtd_attr_string_rec lexbuf 244
and __ocaml_lex_dtd_attr_string_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 663 "xml_lexer.mll"
  (
			Buffer.reset tmp;
			let v = (try dq_string lexbuf with Error EUnterminatedString -> raise (DTDError EInvalidDTDAttribute)) in
			ignore_spaces lexbuf;
			v
		)
# 1592 "xml_lexer.ml"

  | 1 ->
# 670 "xml_lexer.mll"
  (
			Buffer.reset tmp;
			let v = (try q_string lexbuf with Error EUnterminatedString -> raise (DTDError EInvalidDTDAttribute)) in
			ignore_spaces lexbuf;
			v
		)
# 1602 "xml_lexer.ml"

  | 2 ->
# 677 "xml_lexer.mll"
  ( dtd_error lexbuf EInvalidDTDAttribute )
# 1607 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dtd_attr_string_rec lexbuf __ocaml_lex_state

;;

